
import requests
import json
from mcp.server.fastmcp import FastMCP

# 初始化 MCP 服务器
mcp = FastMCP("GbbSearchServer")
#让大模型去匹配商品
@mcp.tool(name="商品匹配",description="根据商品描述，从商品列表中找出满足商品描述的商品")
def difySuit(pro_name:str,pro_list:list) :
    api_key = "app-ibRumVO3acor0yb9EH35YSC2"
    url = 'https://agent-backend-uat.zkh360.com/v1/workflows/run'
    headers = {
        'Authorization': f'Bearer {api_key}',
        'Content-Type': 'application/json'
    }
    print(type(pro_list))
    data = {
        "inputs": {"pro_name":pro_name,"pro_list":json.dumps(pro_list)},
        "response_mode": "blocking",
        "user": "abc-123"
    }
    response = requests.post(url, headers=headers, json=data)
    print("resonse:")
    print(response.text)
    if response.status_code == 200:
        data = json.loads(response.text)
        print(data)
        result = data["data"]["outputs"]["result"]
        temp = json.loads(result)
        skuNo = temp["skuNo"]
        print(skuNo)
        return skuNo
    return ""

def run():
    mcp.run(transport="stdio")

if __name__ == "__main__":
   run()



import requests
from mcp.server.fastmcp import FastMCP

# 初始化 MCP 服务器
mcp = FastMCP("GbbSearchServer")
# 搜索技术
@mcp.tool(name="工邦邦搜索",description="根据输入关键词，去工邦邦官网搜索相关商品")
def search(keyword: str):
    BASE_URL = "https://www.gongbangbang.com"
    url = f"{BASE_URL}/api/gateway/website/gbb/search/product/v2"
    data = {
        "keyword": keyword,
        "channel": 1,
        "clp": False,
        "fz": False,
        "from": 0,
        "size": 20,
        "sort": 0,
    }
    try: 
        response = requests.post(url, headers={"platform": "web"},json=data)
        response.raise_for_status()  # 检查 HTTP 响应的错误
        return response.json()
    except requests.exceptions.RequestException as e:
        print(f"Request failed: {e}")
        return []



import requests
import json
from mcp.server.fastmcp import FastMCP

# 初始化 MCP 服务器
mcp = FastMCP("GbbSearchServer")

#让大模型去修改输入描述，主要是提取商品名称、品牌、型号、参数等
@mcp.tool(name="提取输入关键词",description="根据商品描述，提取商品名称、品牌、型号、参数等")
def difyCollect(pro_name) :
    api_key = "app-rX8oKutNmXaPEms4EUNxmdSs"
    url = 'https://agent-backend-uat.zkh360.com/v1/workflows/run'
    headers = {
        'Authorization': f'Bearer {api_key}',
        'Content-Type': 'application/json'
    }

    data = {
        "inputs": {"input":pro_name},
        "response_mode": "blocking",
        "user": "abc-123"
    }
    response = requests.post(url, headers=headers, json=data)
    if response.status_code == 200:
        data = json.loads(response.text)
        result = data["data"]["outputs"]["text"]
        print(result)
        return result
    return ""

def run():
    mcp.run(transport="stdio")

if __name__ == "__main__":
   run()




from gbb_excel_mcp.gbb import search
from gbb_excel_mcp.pro_suit_dify import difySuit
from gbb_excel_mcp.pro_collect_dify import difyCollect
from mcp.server.fastmcp import FastMCP

# 初始化 MCP 服务器
mcp = FastMCP("GbbSearchServer")

#匹配商品
@mcp.tool(name="工邦邦商品查询",description="根据商品描述，找出满足条件的商品编码")
def suitProWithKey(key:str) :
    """
    工邦邦商品查询工具
    
    根据用户输入的商品描述关键词，查询匹配的商品编码。流程如下：
    1. 使用关键词调用工邦邦搜索获取商品列表
    2. 从搜索结果中匹配最符合的商品编码
    3. 若无匹配结果，则提取新关键词重新搜索匹配
    
    Args:
        key (str): 商品描述关键词
    
    Returns:
        dict: 包含匹配商品编码的字典，格式为 {"skuNo": "商品编码"}
    """
    print("key:"+key)
    # step1 先根据用户输入去调用工邦邦搜索，获取搜索列表
    search_list = search(key)
    # step2 再用用户输入的关键字，从搜索列表中找到满足需求的商品
    skuNo = difySuit(key,search_list)
    # step3 如果没有匹配的商品，即skuNo==“”
    if skuNo == "" :
        # step3.1 修改用户输入，提取关键字
        newKey = difyCollect(key)
        # step3.2 将新的关键字重新去工邦邦搜索
        new_search_list = search(newKey)
        # step 3.3 将新的关键字跟搜索结果去匹配
        skuNo =  difySuit(newKey,search_list)
    return {"skuNo":skuNo}

def main():
    import time
    while True:
        try:
            mcp.run(transport="stdio")
        except Exception as e:
            print(f"Error: {e}")
            time.sleep(1)

if __name__ == "__main__":
    main()



from setuptools import setup, find_packages

setup(
    name="gbb-excel-mcp",  # PyPI 显示的包名（确保唯一性）
    version="0.1.5",    # 初始版本号
    author="wangmeng",
    author_email="meng4.wang@gongbangbang.com",
    description="excel文件中内容匹配工邦邦商品sku",
    long_description=open("README.md").read(),
    long_description_content_type="text/markdown",
    packages=find_packages(),
    install_requires=[],  # 依赖的其他包，如 ["requests>=2.25.1"]
    classifiers=[
        "Programming Language :: Python :: 3",
        "License :: OSI Approved :: MIT License",
        "Operating System :: OS Independent",
    ],
    python_requires=">=3.6",  # Python 版本要求
)
